@@ -18,6 +18,9 @@
 #include <QPixmap>
 #include <QDBusConnection>
 #include <QDBusMessage>
+#include <QLineEdit>
+#include <QComboBox>
+#include <QBrush>
 
 #include <mce/mode-names.h>
 #include <mce/dbus-names.h>
@@ -48,9 +51,12 @@
 const int NAVIGATION_BUTTON_SIZE = 70;
 const int ACTION_BUTTON_SIZE = 70;
 
+int i = 0;
+
 MainWindow::MainWindow()
-    : QMainWindow(), _channelIndex(0), _landscapeOrientation(true)
+    : QMainWindow(), _channelIndex(0), _landscapeOrientation(true), _weeklyMode(false), _dayCount(0)
 {
+	setWindowTitle("SHOWTIME   ver1.1");
 
 	//////////////////////////////////////////////////////////////////	
 	// this is the class that inits and updates the settings file
@@ -105,7 +111,17 @@ MainWindow::MainWindow()
 	_remindButton->setMaximumSize(ACTION_BUTTON_SIZE, ACTION_BUTTON_SIZE);
 	_recordButton->setIcon(QIcon(_settingsWindow->getIconPath() + "record.png"));
 	_remindButton->setIcon(QIcon(_settingsWindow->getIconPath() + "remind.png"));
-	
+
+	// search programme title widgets
+	_searchInput = new QComboBox(this);
+	_searchInput->setEditable(true);
+	_searchInput->setInsertPolicy(QComboBox::NoInsert);
+	_searchInput->setCurrentIndex(-1);
+
+	//_searchInput->setPlaceholderText("Type programme search string");
+	// show them only when search is selected from the menu
+	_searchInput->hide();
+
 	/////////////////////////////////////////////
 	// the list of widgets for the prog detail panel ( see diagram above for layout )
 	/////////////////////////////////////////////
@@ -138,8 +154,6 @@ MainWindow::MainWindow()
 	_clearProgButton->setIcon(QIcon(_settingsWindow->getIconPath() + "clear.png"));
 	_clearProgButton->hide();
 
-
-
 	/////////////////////////////////////////////
 	// the list of widgets for the action panel ( see above diagram for layout detail )
 	/////////////////////////////////////////////
@@ -208,6 +222,8 @@ MainWindow::MainWindow()
 	connect(_programmeDetailButton, SIGNAL(clicked()), this, SLOT(showProgrammeDetailWidget()));
 	connect(_recordButton, SIGNAL(clicked()), this, SLOT(showRecordMessage()));
 	connect(_remindButton, SIGNAL(clicked()), this, SLOT(showRemindMessage()));
+	//connect(_searchInput, SIGNAL(activated(QString)), this, SLOT(addSearchString(QString)));
+	//connect(_searchInput->lineEdit(), SIGNAL(editingFinished()), this, SLOT(setCurrentSearchString()));
 }
 
 // LOADS THE APP SETTINGS TO MEMORY
@@ -267,7 +283,43 @@ void MainWindow::initListModels()
 		dateitem->setTextAlignment(Qt::AlignCenter); // the Maemo 5 design spec recommends this.
 		dateitem->setEditable(false); // prevent editing of the item
 		_dateListModel->appendRow(dateitem);
-		
+	}
+}
+
+void MainWindow::colorDateSelector()
+{
+	//////////////////////////////////////////////////////
+	// COLOR DATE SELECTOR LIST 
+	// Red - means data not in memory, can be tried to download
+	// Green - means data is present in memory , no need to click GO
+	//////////////////////////////////////////////////////
+
+	_dateListModel->clear();
+
+    ChannelMetaData metadata = (_infoapi->metadata())[_currentChannel];
+	QDate minDate = QDate::fromString(metadata.minDate, "yyyyMMdd");
+	QDate maxDate = QDate::fromString(metadata.maxDate, "yyyyMMdd");
+	QSet<QString> availableDateList = metadata.availableDates;
+
+	for(int i = -1; i < 7; ++i )
+	{
+		QStandardItem *dateitem = new QStandardItem(QDate::currentDate().addDays(i).toString());
+		dateitem->setTextAlignment(Qt::AlignCenter); // the Maemo 5 design spec recommends this.
+		dateitem->setEditable(false); // prevent editing of the item
+
+		QBrush brush(Qt::red);
+		// IF the region is a SINGLEXMLTV file region and if the date falls between the min and max then show it as green
+		// OR
+		// IF the region is a per day channel file region and if the date is present in the availableDates then show as green
+		if ( (_infoapi->isSingleXMLTVFile() && QDate::currentDate().addDays(i) >= minDate && QDate::currentDate().addDays(i) <= maxDate  ) ||
+				(!_infoapi->isSingleXMLTVFile()	&& availableDateList.contains(QDate::currentDate().addDays(i).toString("yyyyMMdd")) )
+		   )
+			brush.setColor(Qt::green);
+		else
+			brush.setColor(Qt::red);
+		dateitem->setForeground(brush);
+
+		_dateListModel->appendRow(dateitem);
 	}
 }
 
@@ -277,6 +329,7 @@ void MainWindow::createMenus()
 	regionAct = new QAction(tr("&REGION"), this);
 	favAct = new QAction(tr("&FAVOURITES"), this);
 	setAct = new QAction(tr("&SETTINGS"), this);
+	modeAct = new QAction(tr("&SWITCH MODE"), this);
 	//openxmlAct = new QAction(tr("&LOAD XMLTV"), this);
 	helpAct = new QAction(tr("&HELP"), this);
 	donateAct = new QAction(tr("&DONATE"), this);
@@ -284,6 +337,7 @@ void MainWindow::createMenus()
 	connect(regionAct, SIGNAL(triggered()), this , SLOT(showRegion()));
 	connect(favAct, SIGNAL(triggered()), this , SLOT(showFavourite()));
 	connect(setAct, SIGNAL(triggered()), this , SLOT(showSettings()));
+	connect(modeAct, SIGNAL(triggered()), this , SLOT(switchMode()));
 	//connect(openxmlAct, SIGNAL(triggered()), this , SLOT(loadXMLTV()));
 	connect(helpAct, SIGNAL(triggered()), this , SLOT(showHelp()));
 	connect(donateAct, SIGNAL(triggered()), this , SLOT(showDonate()));
@@ -292,6 +346,7 @@ void MainWindow::createMenus()
 	menu->addAction(regionAct);
 	menu->addAction(favAct);
 	menu->addAction(setAct);
+	menu->addAction(modeAct);
 	//menu->addAction(openxmlAct);
 	menu->addAction(helpAct);
 	menu->addAction(donateAct);
@@ -343,17 +398,36 @@ void MainWindow::showProgrammeListWidgetButtons()
 	_backToProgrammeListButton->hide();
 	_programmeList->show();
 	_channelSelector->show();
-	_dateSelector->show();
+
+	if ( _weeklyMode )
+	{
+		_searchInput->show();
+		_searchInput->clear();
+		_searchInput->addItems(_settingsWindow->getSearchTitles(_settingsWindow->getRegion(), _currentChannel));
+		_searchInput->lineEdit()->setText(_searchStringPerChannelMap[_currentChannel]);
+	}
+	else
+		_dateSelector->show();
+
 	_clearButton->show();
 	_nextChannelButton->show();
 	_prevChannelButton->show();
 
 	showNextPrevChannelButtons();
 }
-		
+
 // The method that calls the infoaccess class to download/read xmltv info into local memory
 void MainWindow::go()
 {
+	/////////////////////////////////////////////////////////////////
+	// if its weekly download go to the goWeekly, dont do anything else
+	if ( _weeklyMode )
+	{
+		goWeekly();
+		return;
+	}
+	/////////////////////////////////////////////////////////////////
+
 	if (_channelSelector->valueText() == "" || _dateSelector->valueText() == "")
 		return;
 
@@ -361,15 +435,33 @@ void MainWindow::go()
 
 	_currentDate = QDate::fromString(_dateSelector->valueText(), Qt::TextDate);
 
-	showProgrammeListWidgetButtons();
+	// this indicator will be set to false if the requested date > maxDate for the channel
+	bool downloadFresh = true;
+	// the XMLTV files that are single per channel are huge so we dont want to download every time a user requests
+	// a date that is not available already. We download only if the data is 3 days old atleast unless user forces 
+	// us to go forward and download fresh
+	if ( _infoapi->isSingleXMLTVFile() )
+		downloadFresh = isRequestMoreThanMaxDate();
 
 	DownloadInput d;
 	d.requestDate = QDate::fromString(_dateSelector->valueText(), Qt::TextDate);
 	d.requestChannel = _currentChannel;
 
-	bool dataDownloaded = _infoapi->getChannelInfo(d);
+	bool dataDownloaded = false;
 
-	toggleBusy(true);
+	// if the indicator to download fresh is not false and the data is not contained locally in the map then download/read from file
+	// so that means you are basically prevented from downloading data if you request a date thats not in the local map
+	// and if that date is higher than the max available data date for the channel
+	if ( downloadFresh && ! _channelDataAvailableMap[_currentChannel].contains(_currentDate.toString("yyyyMMdd")) )
+	{
+		toggleBusy(true);
+		dataDownloaded = _infoapi->getChannelInfo(d);
+	}
+	else
+	{
+		//qDebug() << "channel data already in memory";
+		finished();
+	}
 
 	// Call the callback slot finished explicitly here as its not called if data isnot downloaded
 	if (!dataDownloaded)
@@ -437,6 +529,8 @@ void MainWindow::clearAll()
 	_channelsSelected.clear();
 	_channelIndex = 0;
 	_channelDataMap.clear();
+	_channelDataAvailableMap.clear();
+	_searchStringPerChannelMap.clear();
 	_currentChannel.clear();
 	_programmeList->clear();
 	_programmeDetail->clear();
@@ -449,6 +543,7 @@ void MainWindow::clearAll()
 	_dateSelector->setValueText("");
 	_channelSelector->setText("PICK CHANNELS");
 	_dateSelector->setValueText(QDate::currentDate().toString());
+	_searchInput->clear();
 }
 
 // CLEAR selected programmes list
@@ -463,12 +558,23 @@ void MainWindow::finished(bool dataRequested)
 {
 	//qDebug() << "In finished";
 
-	toggleBusy(false);
 	_infoLabel->hide();
 
-	// we pass the dataRequested here to indicate that we are calling the below method
-	// after requesting data since it wasnt available in the local channelDataMap
-	return showProgrammeListWidget(true);
+	_channelDataAvailableMap[_currentChannel] = _infoapi->metadata()[_currentChannel].availableDates;
+
+	if ( _weeklyMode )
+	{
+		// call the weekly download finished to check if we are finished 
+		finishedWeekly();
+	}
+	else
+	{
+		toggleBusy(false);
+
+		// we pass the dataRequested here to indicate that we are calling the below method
+		// after requesting data since it wasnt available in the local channelDataMap
+		return showProgrammeListWidget(true);
+	}
 }
 
 
@@ -483,13 +589,38 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 	
     QList<ChannelData> completeData = (_infoapi->results())[_currentChannel];
 
+	// marks available dates as green and others as red
+	colorDateSelector();
+
 	//qDebug() << _infoapi->results()[_currentChannel];
 
 	bool dataAvailable = false;
 
+	/////////////////////////////////////////////////////////////
+	/////////////////// CHECK THE SETTINGS //////////////////////
+	
+	// hide listings < currentdatetime ?
+	bool hidePastListings = (_settingsWindow->getShowPastInd() == "N") ? true : false;
+
+	// see if prime time is set , then only show listings b/w those times
+	bool primeTimeSet = false;
+	QTime startPrimeTime = QTime::fromString(_settingsWindow->getPrimeTimeStart(), "hh:mm");
+	QTime endPrimeTime = QTime::fromString(_settingsWindow->getPrimeTimeEnd(), "hh:mm");
+	if ( _settingsWindow->getPrimeTimeStart() == "00:00" && _settingsWindow->getPrimeTimeEnd() == "00:00" )
+		primeTimeSet = false;
+	else
+		primeTimeSet = true;
+
+	// if weekly mode , see if the title matches the search input
+	bool titleMatched = true;
+	/////////////// END OF CHECK THE SETTINGS ///////////////////
+	/////////////////////////////////////////////////////////////
+	
 	foreach(ChannelData data, completeData)
 	{
+		QDateTime progSDateTime = QDateTime::fromString(data.sdate + data.stime, "ddd MMM d yyyyHH:mm:ss");
 		QString title = data.title;
+		QString sdate = data.sdate;
 		QString stime = data.stime;
 		stime.truncate(5);
 		QString etime = data.etime;
@@ -502,19 +633,68 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 		QString keyForInsert;
 		if ( _landscapeOrientation )
 		{
-			keyForDisplay = title + "\n\t\t\t\t\t\t" + time;
-			//keyForInsert = title + "\n\t\t\t\t\t\t" + time + "\t" + data.sdate;
-			keyForInsert = title + " " + time + " " + data.sdate;
+			if ( _weeklyMode ) // less tabs for weekly as we have date also
+			{
+				keyForDisplay = title + "\n\t\t\t\t" + sdate + " : " + time;
+				keyForInsert = title + "\n\t\t\t\t" + sdate + " : " + time;
+			}
+			else
+			{
+				keyForDisplay = title + "\n\t\t\t\t\t\t" + time;
+				keyForInsert = title + " " + time + " " + data.sdate;
+			}
 		}
 		else // in portrait mode we need less tabs to prevent horizontal scrolling
 		{
-			keyForDisplay = title + "\n\t\t\t" + time;
-			keyForInsert = title + " " + time + " " + data.sdate;
+			if ( _weeklyMode ) // less tabs for weekly as we have date also
+			{
+				keyForDisplay = title + "\n" + sdate + " : " + time;
+				keyForInsert = title + "\n" + sdate + " : " + time;
+			}
+			else
+			{
+				keyForDisplay = title + "\n\t\t\t" + time;
+				keyForInsert = title + " " + time + " " + data.sdate;
+			}
 		}
 
-		if ( data.sdate == _currentDate.toString(Qt::TextDate) )
+		// see if title matches the search string in weekly search mode
+		if ( _weeklyMode )
 		{
-			_programmeList->addItem(keyForDisplay);
+			titleMatched = false;
+
+			QStringList searchList = _searchInput->currentText().split(" + ", QString::SkipEmptyParts);
+			foreach(QString searchString, searchList)
+			{
+				if ( data.title.contains(searchString, Qt::CaseInsensitive))
+				{
+					titleMatched = true;
+					break;
+				}
+			}
+		}
+		else
+		{
+			titleMatched = true;
+		}
+
+		// if its weekly mode then check if title matches else check if programme start date matches the user chosen date
+		if ( (!_weeklyMode && data.sdate == _currentDate.toString(Qt::TextDate)) || (_weeklyMode && titleMatched) )
+		{
+			if ( hidePastListings && progSDateTime < QDateTime::currentDateTime() )
+			{
+				continue;
+			}
+
+			if ( primeTimeSet && (QTime::fromString(stime, "hh:mm") < startPrimeTime || QTime::fromString(stime, "hh:mm") > endPrimeTime) ) 
+			{
+				continue;
+			}
+		
+			QListWidgetItem *item = new QListWidgetItem(keyForDisplay, _programmeList);	
+			QBrush brush(Qt::cyan);
+			if ( (i++ % 2 ) ) item->setForeground(brush);
+			_programmeList->addItem(item);
 			_channelDataMap[keyForInsert] = data;
 			dataAvailable = true;
 		}
@@ -522,9 +702,15 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 	// this means that data is not available locally in channelDataMap and also it hasnt been
 	// requested so it means you have to hit GO :-) !
 	if ( !dataRequested && !dataAvailable )
-		showInfoLabel( QString("<b>HIT GO !<\b>\n") + QString("\n\n*Note data may be unavailable for some channels for some/all dates") );
+	{
+		if ( _weeklyMode )	showInfoLabel( QString("<b>HIT SEARCH !<\b>\n") + QString("\n\n*Note data may be unavailable for some channels for some/all dates") );
+		else 				showInfoLabel( QString("<b>HIT GO !<\b>\n") + QString("\n\n*Note data may be unavailable for some channels for some/all dates") );
+	}
 	else if ( dataRequested && !dataAvailable )
-		showInfoLabel( QString("<b>NO DATA AVAILABLE FOR THIS CHANNEL !<\b>") );
+	{
+		if ( _weeklyMode )	showInfoLabel( QString("Sorry, requested programme title does not exist in the available data for the channel.\nSwitch Modes and click GO to check the dates for which data is available(marked in green), you could try refreshing your data in case its old.") );
+		else				showInfoLabel( QString("<b>NO DATA AVAILABLE FOR THIS CHANNEL !<\b>") );
+	}
 
 }
 
@@ -572,7 +758,7 @@ void MainWindow::showNextChannel()
 	showNextPrevChannelButtons();
 
 	// shows the data for the channel if available for selected date
-	showProgrammeListWidget();
+	showProgrammeListWidget(false);
 }
 
 // show previous selected channel
@@ -585,7 +771,7 @@ void MainWindow::showPrevChannel()
 	showNextPrevChannelButtons();
 
 	// shows the data for the channel if available for selected date
-	showProgrammeListWidget();
+	showProgrammeListWidget(false);
 }
 
 // make sure we are showing the next/prev arrows correctly
@@ -624,9 +810,17 @@ void MainWindow::showNextPrevChannelButtons()
 void MainWindow::addProgrammeActionList(QListWidgetItem* programme)
 {
 	QString key;
+	// IF its weekly search mode then the key is what is shown on the listwidget
+	// ELSE if its daily mode we dont show the date so that needs to be appended to the key
+	if ( _weeklyMode )
+	{
+		key = programme->text();
+	}
 	// add the date to the listwidgetitem as in the list we dont display the date
-	if ( _dateSelector->valueText() != "" )
+	else if ( _dateSelector->valueText() != "" )
+	{
 		key = (programme->text() + "\t" + _dateSelector->valueText()).simplified();
+	}
 
 	// on clicking this slot is called so
 	// if the program exists then remove it ( as user deselected) else add it(user selected)
@@ -648,7 +842,7 @@ void MainWindow::showRecordMessage()
 {
     if ( _settingsWindow->getRegion() != "UK" )
     {
-		QMaemo5InformationBox::information(this, "SORRY THIS FUNCTIONALITY IS ONLY SUPPORTED BY UK AT THE MOMENT, if you are aware of any support for your region, please let me know either in my thread talk.maemo or send me an email" , QMaemo5InformationBox::NoTimeout);
+		QMaemo5InformationBox::information(this, "<font color=#000000>SORRY THIS FUNCTIONALITY IS ONLY SUPPORTED BY UK AT THE MOMENT, if you are aware of any support for your region, please let me know either in my thread talk.maemo or send me an email</font>" , QMaemo5InformationBox::DefaultTimeout);
 
         return;
     }
@@ -706,7 +900,7 @@ void MainWindow::showRemindMessage()
 	}
 
 	if(_programmeSetForAction.count() != 0)
-		QMaemo5InformationBox::information(this, "<b>YOUR SHOWTIME CALENDAR HAS BEEN UPDATED WITH YOUR SELECTED PROGRAMMES<\b>" , QMaemo5InformationBox::NoTimeout);
+		QMaemo5InformationBox::information(this, "<font color=#000000><b>YOUR SHOWTIME CALENDAR HAS BEEN UPDATED WITH YOUR SELECTED PROGRAMMES</b></font>" , QMaemo5InformationBox::DefaultTimeout);
 
 	clearProg();  // clear selected programmes
 }
@@ -715,22 +909,26 @@ void MainWindow::showRemindMessage()
 void MainWindow::setLandscape()
 {
 	initLandscape();
-	setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, true);
+	setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
 	setCentralWidget(_landscapeMainWidget);
 
 	_landscapeOrientation = true;
 	_programmeList->clear(); // have to do this as we are doing some manual formatting to display the programmes and times
+
+	showProgrammeListWidget();
 }
 
 // set the app widgets to portrait mode
 void MainWindow::setPortrait()
 {
 	initPortrait();
-	setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
+	setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
 	setCentralWidget(_portraitMainWidget);
 
 	_landscapeOrientation = false;
 	_programmeList->clear(); // have to do this as we are doing some manual formatting to display the programmes and times
+
+	showProgrammeListWidget();
 }
 
 // init the landscape layout
@@ -746,6 +944,7 @@ void MainWindow::initLandscape()
 	_landscapeMainWidget = new QWidget(this);
 	
 	// define the selection panel layout	
+	_lh1layout->addWidget(_searchInput);
 	_lh1layout->addWidget(_programmeDetailLabel);
 	_lh1layout->addWidget(_dateSelector);
 	_lh1layout->addWidget(_recordButton);
@@ -794,6 +993,7 @@ void MainWindow::initPortrait()
 	_ph1layout->addWidget(_recordButton);
 
 	// date selector with remind
+	_ph2layout->addWidget(_searchInput); // this is available only in the search option
 	_ph2layout->addWidget(_dateSelector);
 	_ph2layout->addWidget(_remindButton);
 	_ph2layout->addWidget(_clearProgButton); // this is available in programme detail mode only
@@ -830,6 +1030,7 @@ MainWindow::~MainWindow()
 // slot to load your own xmltv file
 void MainWindow::loadXMLTV()
 {
+	//disableAllWidgets();
 	QString filename(_settingsWindow->getBinPath() + "xmltvfile.xml");
 	_infoapi->processXMLTV(filename);
 }
@@ -875,10 +1076,41 @@ void MainWindow::showSettings()
 	_miscWindow->show();
 }
 
+// slot to search for the title string in the selected channel for the week
+void MainWindow::switchMode()
+{
+	//clearAll();
+
+	if ( _weeklyMode )
+	{
+		_dateSelector->show();
+		_searchInput->hide();
+		_weeklyMode = false;
+	
+		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "go.png"));
+	}
+	else
+	{
+		_dateSelector->hide();
+		_searchInput->show();
+		_weeklyMode = true;
+		_searchInput->clear();
+		_searchInput->addItems(_settingsWindow->getSearchTitles(_settingsWindow->getRegion(), _currentChannel));
+		_searchInput->lineEdit()->setText(_searchStringPerChannelMap[_currentChannel]);
+
+		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "search.png"));
+	}
+}
+
 // SLOT::reloads the favourite settings
 void MainWindow::reInitFavouriteSettings()
 {
 	initAppSettings();
+
+	_searchInput->clear();
+	_searchInput->addItems(_settingsWindow->getSearchTitles(_settingsWindow->getRegion(), _currentChannel));
+	_searchInput->lineEdit()->setText(_searchStringPerChannelMap[_currentChannel]);
+
 	_favouriteWindow->close();
 }
 
@@ -911,7 +1143,10 @@ void MainWindow::reInitMiscSettings()
 	_remindButton->setIcon(QIcon(_settingsWindow->getIconPath() + "remind.png"));
 	_backToProgrammeListButton->setIcon(QIcon(_settingsWindow->getIconPath() + "back.png"));
 	_clearProgButton->setIcon(QIcon(_settingsWindow->getIconPath() + "clear.png"));
-	_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "go.png"));
+	if ( _weeklyMode )
+		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "search.png"));
+	else
+		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "go.png"));
 	_clearButton->setIcon(QIcon(_settingsWindow->getIconPath() + "clear.png"));
 	_programmeDetailButton->setIcon(QIcon(_settingsWindow->getIconPath() + "detail.png"));
 	_nextChannelButton->setIcon(QIcon(_settingsWindow->getIconPath() + "next.png"));
@@ -972,5 +1207,121 @@ void MainWindow::showHelp()
 	_helpWindow->show();
 }
 
+bool MainWindow::isRequestMoreThanMaxDate()
+{
+	bool result = true;
+    QStringList keylist = _infoapi->metadata().keys();
+	if ( keylist.contains(_currentChannel) )
+	{
+    	ChannelMetaData metadata = _infoapi->metadata()[_currentChannel];
+		QDate downloadedDate = QDate::fromString(metadata.downloadedDate, "yyyyMMdd");
+		QDate maxDate = QDate::fromString(metadata.maxDate, "yyyyMMdd");
+	
+		if ( _currentDate > maxDate )
+		{
+			if ( downloadedDate.daysTo(QDate::currentDate()) < 3 )
+			{
+				QMessageBox::StandardButton ret;
+				QString question = "The data you have is only " + QString::number(downloadedDate.daysTo(QDate::currentDate())) + " days old.\n" +
+								"Maybe you should wait till its atleast 3 days old so the chances that the source has the data is higher.\n" +
+								"If you still wish to proceed click YES else click NO to use available data";
+				ret = QMessageBox::question(this, tr("Early Download Warning !"), question ,QMessageBox::Yes | QMessageBox::No);
+				if (ret == QMessageBox::Yes)
+					result = true;
+				else if (ret == QMessageBox::No)
+					result = false;
+			}
+			else
+			{
+				result = true; // if its more than 3 days old no need to ask the user just download :-)
+			}
+		}
 
+	}
+	return result;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////// SEARCH TITLE FUNCTIONALITY //////////////////////////////////////
+///////////////////////////////////////// introduced in version 1.0-8 //////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////////////////////////////////
+//
+// The method that calls the infoaccess class to download/read xmltv weekly data and calls the search function
+void MainWindow::goWeekly(QDate date)
+{
+	if (_channelSelector->valueText() == "" || _searchInput->currentText() == "")
+		return;
+
+	//qDebug() << "In GoWeekly : " << _channelSelector->valueText() << " " << date;
+
+	// store the current search string for the channel so when you press the arrow keys your
+	// search is also remembered :-)	
+	_searchStringPerChannelMap[_currentChannel] = _searchInput->currentText();
+	_currentSearchString = _searchInput->currentText();
+
+	DownloadInput d;
+	d.requestChannel = _currentChannel;
+	d.requestDate = date;
+
+	if ( ! _channelDataAvailableMap[_currentChannel].contains(date.toString("yyyyMMdd")) )
+	{
+		// in case of single XMLTV files we dont want to download files greater than max date avaialble for the channel
+		// we simply search in the avaialable data, the user can switch mode to see what data is available
+		if ( !_infoapi->isSingleXMLTVFile() || (date == QDate::currentDate() || date.toString("yyyyMMdd") <= _infoapi->metadata()[_currentChannel].maxDate ) )
+		{
+			toggleBusy(true);
+			_infoapi->getChannelInfo(d);
+		}
+		else
+		{
+			//qDebug() << "the Date requested was more than the max date of channel";
+			finished();
+		}
+	}
+	else
+	{
+		//qDebug() << "channel data already in memory";
+		finished();
+	}
+}
+
+// called from a callback (finished) when the XMLTV info required is downloaded/read
+void MainWindow::finishedWeekly()
+{
+	_infoLabel->hide();
+
+	// if we have finished downloaded the files for the week	
+	if ( _dayCount == 6 )
+	{
+		_dayCount = 0;
+		toggleBusy(false);
+		showProgrammeListWidget(true);
+	}
+	else // keep downloading the files
+	{
+		++_dayCount;
+		goWeekly(QDate::currentDate().addDays(_dayCount));
+	}
+
+	return;
+}
+
+// SLOT : to append the favourite search strings to the current
+void MainWindow::addSearchString(QString text)
+{
+	if ( _currentSearchString.simplified() == "" ) 
+		_currentSearchString += text;
+	else
+		_currentSearchString += " + "  + text;
+
+	_searchInput->lineEdit()->setText(_currentSearchString);
+}
+
+// SLOT : to set the current search string
+void MainWindow::setCurrentSearchString()
+{
+	_currentSearchString = _searchInput->currentText();
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////############## END OF SHOWTIM ###############////////////////////////////////////////////////
